==> camel-k-model-v1alpha1-6.1.1-sources.jar: io/fabric8/camelk/v1alpha1/JSONSchemaPropsFluent.java <==
package io.fabric8.camelk.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface JSONSchemaPropsFluent<A extends JSONSchemaPropsFluent<A>> extends Fluent<A>{
  public String getSchema();
  public A withSchema(String $schema);
  public Boolean hasSchema();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public JsonNode getExample();
  public A withExample(JsonNode example);
  public Boolean hasExample();
  
  /**
   * This method has been deprecated, please use method buildExternalDocs instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExternalDocumentation getExternalDocs();
  public ExternalDocumentation buildExternalDocs();
  public A withExternalDocs(ExternalDocumentation externalDocs);
  public Boolean hasExternalDocs();
  public A withNewExternalDocs(String description,String url);
  public JSONSchemaPropsFluent.ExternalDocsNested<A> withNewExternalDocs();
  public JSONSchemaPropsFluent.ExternalDocsNested<A> withNewExternalDocsLike(ExternalDocumentation item);
  public JSONSchemaPropsFluent.ExternalDocsNested<A> editExternalDocs();
  public JSONSchemaPropsFluent.ExternalDocsNested<A> editOrNewExternalDocs();
  public JSONSchemaPropsFluent.ExternalDocsNested<A> editOrNewExternalDocsLike(ExternalDocumentation item);
  public String getId();
  public A withId(String id);
  public Boolean hasId();
  public A addToProperties(String key,JSONSchemaProp value);
  public A addToProperties(Map<String,JSONSchemaProp> map);
  public A removeFromProperties(String key);
  public A removeFromProperties(Map<String,JSONSchemaProp> map);
  public Map<String,JSONSchemaProp> getProperties();
  public <K,V>A withProperties(Map<String,JSONSchemaProp> properties);
  public Boolean hasProperties();
  public A addToRequired(Integer index,String item);
  public A setToRequired(Integer index,String item);
  public A addToRequired(java.lang.String... items);
  public A addAllToRequired(Collection<String> items);
  public A removeFromRequired(java.lang.String... items);
  public A removeAllFromRequired(Collection<String> items);
  public List<String> getRequired();
  public String getRequired(Integer index);
  public String getFirstRequired();
  public String getLastRequired();
  public String getMatchingRequired(Predicate<String> predicate);
  public Boolean hasMatchingRequired(Predicate<String> predicate);
  public A withRequired(List<String> required);
  public A withRequired(java.lang.String... required);
  public Boolean hasRequired();
  public String getTitle();
  public A withTitle(String title);
  public Boolean hasTitle();
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public interface ExternalDocsNested<N> extends Nested<N>,ExternalDocumentationFluent<JSONSchemaPropsFluent.ExternalDocsNested<N>>{
    public N and();
    public N endExternalDocs();
    
  }
  
}

==> camel-k-model-v1alpha1-6.7.1-sources.jar: io/fabric8/camelk/v1alpha1/JSONSchemaPropsFluent.java <==
package io.fabric8.camelk.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface JSONSchemaPropsFluent<A extends JSONSchemaPropsFluent<A>> extends Fluent<A>{
  public String getSchema();
  public A withSchema(String $schema);
  public Boolean hasSchema();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public JsonNode getExample();
  public A withExample(JsonNode example);
  public Boolean hasExample();
  
  /**
   * This method has been deprecated, please use method buildExternalDocs instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExternalDocumentation getExternalDocs();
  public ExternalDocumentation buildExternalDocs();
  public A withExternalDocs(ExternalDocumentation externalDocs);
  public Boolean hasExternalDocs();
  public A withNewExternalDocs(String description,String url);
  public JSONSchemaPropsFluent.ExternalDocsNested<A> withNewExternalDocs();
  public JSONSchemaPropsFluent.ExternalDocsNested<A> withNewExternalDocsLike(ExternalDocumentation item);
  public JSONSchemaPropsFluent.ExternalDocsNested<A> editExternalDocs();
  public JSONSchemaPropsFluent.ExternalDocsNested<A> editOrNewExternalDocs();
  public JSONSchemaPropsFluent.ExternalDocsNested<A> editOrNewExternalDocsLike(ExternalDocumentation item);
  public String getId();
  public A withId(String id);
  public Boolean hasId();
  public A addToProperties(String key,JSONSchemaProp value);
  public A addToProperties(Map<String,JSONSchemaProp> map);
  public A removeFromProperties(String key);
  public A removeFromProperties(Map<String,JSONSchemaProp> map);
  public Map<String,JSONSchemaProp> getProperties();
  public <K,V>A withProperties(Map<String,JSONSchemaProp> properties);
  public Boolean hasProperties();
  public A addToRequired(int index,String item);
  public A setToRequired(int index,String item);
  public A addToRequired(java.lang.String... items);
  public A addAllToRequired(Collection<String> items);
  public A removeFromRequired(java.lang.String... items);
  public A removeAllFromRequired(Collection<String> items);
  public List<String> getRequired();
  public String getRequired(int index);
  public String getFirstRequired();
  public String getLastRequired();
  public String getMatchingRequired(Predicate<String> predicate);
  public Boolean hasMatchingRequired(Predicate<String> predicate);
  public A withRequired(List<String> required);
  public A withRequired(java.lang.String... required);
  public Boolean hasRequired();
  public String getTitle();
  public A withTitle(String title);
  public Boolean hasTitle();
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public interface ExternalDocsNested<N> extends Nested<N>,ExternalDocumentationFluent<JSONSchemaPropsFluent.ExternalDocsNested<N>>{
    public N and();
    public N endExternalDocs();
    
  }
  
}
